<?php
/**
 *  Copyright (c) Microsoft. All rights reserved. Licensed under the MIT license.
 *  See LICENSE in the project root for license information.
 *
 *  PHP version 5
 *
 *  @category Code_Sample
 *  @package  php-connect-rest-sample
 *  @author   Ricardo Loo <ricardol@microsoft.com>
 *  @license  MIT License
 *  @link     http://github.com/microsoftgraph/php-connect-rest-sample
 */

namespace Microsoft\Graph\Connect;

/**
 *  Sends POST requests to the specified endpoint.
 *  It's used by AuthenticationManager to get OAuth tokens and
 *  MailManager to contact Microsoft Graph.
 *
 *  @class    RequestManager
 *  @category Code_Sample
 *  @package  php-connect-rest-sample
 *  @author   Ricardo Loo <ricardol@microsoft.com>
 *  @license  MIT License
 *  @link     http://github.com/microsoftgraph/php-connect-rest-sample
 */
class OnedriveManager
{
    
    /**
     *  Helper method to send a POST request.
     *
     *  @param string $endpoint The endpoint to send the request to.
     *  @param array  $headers  Array of key-value pairs that form the header.
     *  @param array  $body     Array of key-value pairs that form the body.
     *
     *  @function sendPostRequest
     *  @return   string The raw response returned by the endpoint.
     */
    public static function sendPostRequest($endpoint, $headers)
    {

         //echo "<pre>";print_r($endpoint);exit;
        $ch = curl_init();      
        curl_setopt($ch, CURLOPT_URL, $endpoint);       
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);    
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);   
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);    
        $data = json_decode(curl_exec($ch), true); 
        
        $http_code = curl_getinfo($ch,CURLINFO_HTTP_CODE);
        //print_r($http_code);exit;              
        if($http_code != 200) 
            throw new Exception('Error : Failed to get timezone');


        //echo "<pre>";print_r($data);exit;
        
        return $data;

    }
}
